#!/bin/bash

sleep 10

# File paths
ORIENTATION_FILE="/home/siedle/.config/siedle/Orientation.json"
DEVICE_PARAMETER_FILE="/home/siedle/.config/siedle/DeviceParameter.json"

# Check if DeviceParameter.json exists
if [ ! -f "$DEVICE_PARAMETER_FILE" ]; then
  echo "DeviceParameter file not found!"
  exit 1
fi

# Read deviceType from DeviceParameter.json
DEVICE_TYPE=$(jq -r '.deviceType' "$DEVICE_PARAMETER_FILE")

# If deviceType is ST5, set orientation to portrait_down regardless of Orientation.json
if [ "$DEVICE_TYPE" == "ST5" ]; then
  FLUTTER_ORIENTATION="portrait_down"
else
  # Check if Orientation.json exists
  if [ ! -f "$ORIENTATION_FILE" ]; then
    echo "Orientation file not found!"
    exit 1
  fi

  # Read orientation from Orientation.json
  ORIENTATION=$(jq -r '.orientation' "$ORIENTATION_FILE")

  # Set the orientation parameter for flutter-pi
  case "$ORIENTATION" in
    "LANDSCAPE")
      FLUTTER_ORIENTATION="landscape_left"
      ;;
    "PORTRAIT")
      FLUTTER_ORIENTATION="portrait_down"
      ;;
    *)
      echo "Unknown orientation: $ORIENTATION"
      exit 1
      ;;
  esac
fi

# Set dmesg logging level to 1 (KERN_EMERG)
dmesg -n 1

# Start flutter-pi with the appropriate orientation
/usr/local/bin/flutter-pi --orientation $FLUTTER_ORIENTATION --release /opt/st10/st10flutterpi &> /dev/null
